# Softwares used in the {{ name }} module


## [Dummy](url_to_tool)
Dummy will ... DNA


### :snake: Rule

#SNAKEMAKE_RULE_SOURCE__dummy__dummy#

#### :left_right_arrow: input / output files

#SNAKEMAKE_RULE_TABLE__dummy__dummy#

### :wrench: Configuration

#### Software settings (`config.yaml`)

#CONFIGSCHEMA__dummy#

#### Resources settings (`resources.yaml`)

#RESOURCESSCHEMA__dummy#